@@ -1,25 +1,25 @@
 # -*- coding: utf-8 -*-
 
-from decimal import Decimal, ROUND_DOWN
+from decimal import (
+    Decimal,
+    ROUND_DOWN
+)
 
 
 class Amount(object):
 
-    def __init__(self, value, auto_round=True):
+    def __init__(self, value):
 
-        # auto_round 是否自动规范精度
-        # hipopay采取货币最小单位分为基本计价单位，
-        # 所以这里直接舍掉小数位
-        self._value = Decimal(
-            value
-        ).quantize(
-            Decimal('0'),
-            ROUND_DOWN
-        ) if auto_round else value
+        self._value = Decimal(value)
 
     @property
     def value(self):
-        return self._value
+        # hipopay采取货币最小单位分为基本计价单位，
+        # 所以这里直接舍掉小数位
+        return self._value.quantize(
+            Decimal('0'),
+            ROUND_DOWN
+        )
 
     def __str__(self):
         return f'{self._value}'
